@@ -1,13 +1,13 @@
 #' Royal Statistical Society Journal Format
 #'
-#' Format for creating articles for Royal Statistical Society Adapted from
-#' \url{https://www.rss.org.uk/RSS/Publications/Journals/Journals_get_involved/RSS/Publications/Journals_sub/Get_Involved.aspx}.
+#' Format for creating articles for Royal Statistical Society adapted from
+#' \url{https://rss.org.uk/news-publication/publications/journals/submit-paper/}.
 #' @inheritParams rmarkdown::pdf_document
 #' @param ... Arguments to \code{rmarkdown::pdf_document}
 #' @export
 rss_article <- function(..., keep_tex = TRUE, citation_package = "natbib") {
   fmt <- pdf_document_format(
-    "rss_article", highlight = NULL, citation_package = citation_package,
+    "rss", highlight = NULL, citation_package = citation_package,
     keep_tex = keep_tex, ...
   )
   fmt$knitr$knit_hooks$source <- function(x, options) {
